<?php

$plugin_info = array(
  'pi_name' => 'Delete Entries',
  'pi_version' => '1.0',
  'pi_author' => 'Dom Stubbs',
  'pi_author_url' => 'http://www.vayadesign.net',
  'pi_description' => 'Allows a user to delete their entries outside of the control panel.',
  'pi_usage' => Delete_entry::usage()
  );

class Delete_entry
{

// Config
var $permission_error = "<strong>Error:</strong> You do not have permission to delete this entry.<br>";
var $invalid_entry = "<strong>Error:</strong> This entry does not exist or has already been deleted.<br>";
var $successmsg = "Entry successfully deleted!";
var $returntext = "Return to the previous page"; // A link to the previous page can be displayed upon deletion; this is the text it uses.
// End config 

var $usermessage = "";
  
  // Generate an entry-specific delete link  
  function link()
  {
     global $TMPL, $PREFS;
	 
	 if (!$TMPL->fetch_param('entryid') OR !$TMPL->fetch_param('template')) {
	 	return "Invalid delete_entry plugin usage.";
	 }
	 
	 // Determine the phrase used for an entry. 
	 $entrytype = ($TMPL->fetch_param('entrytype') ? $TMPL->fetch_param('entrytype') : 'entry');
	 
	 // Generate a javascript confirmation box unless the user requests otherwise
	 if($TMPL->fetch_param('showconfirm') != "false")
	 {
	 	$showconfirm = " onclick=\"javascript: if (!confirm('Are you sure you want to delete this $entrytype?')) return false;\"";
	 }
	 $link = "<a href=\"" . $PREFS->ini('site_url') . $PREFS->ini('site_index') . "/" . 
	 $TMPL->fetch_param('template') . "/" . $TMPL->fetch_param('entryid') . "\"$showconfirm>" . $TMPL->tagdata . "</a>";
	 return $link;
  
  }
  
  function delete()
  {
     global $IN, $TMPL, $DB, $FNS, $SESS, $STAT, $PREFS; 
	 
	 $entryid = $IN->SEGS[3];
	 
	 // Is entryid valid?
	 if(! (is_numeric($entryid) && is_int($entryid + 0)) ) {
	 	$this->usermessage = "Invalid entry id";
		return $this->usermessage;
	 } 
	 
	 // Does this entry even exist?
	 $query = $DB->query("SELECT * FROM exp_weblog_titles WHERE entry_id = $entryid");
	 
	 if ($query->num_rows < 1)
	 {	 
	 	$this->usermessage .= $this->invalid_entry;
		return $this->usermessage;
	 }
	 
	 $authorid = $query->row['author_id'];
	 $weblog_id = $query->row['weblog_id'];
	 
	 // Check user's permissions allow them to delete this entry
	 if($SESS->userdata['group_id'] != 1) { // Superadmins automatically bypass access level checks
	 
		 // Is this user allowed to delete his own posts? Is he/she allowed to delete other user's posts?
        if ( ! $SESS->userdata('can_delete_self_entries') AND
             ! $SESS->userdata('can_delete_all_entries'))
        {
		 	$this->usermessage .= $this->permission_error;
			return $this->usermessage;
        }
				
		 // Is this user assigned access to the blog to which this entry belongs?	  
		 $hasweblogaccess = false;
		 foreach ($FNS->fetch_assigned_weblogs() as $key => $val) { 
		 	if($val == $weblog_id) {
				$hasweblogaccess = true;
			}
		 }
		 if($hasweblogaccess == false) {
		 	$this->usermessage .= $this->permission_error;
			return $this->usermessage;
		 }
		 
		 // Is this user allowed to delete his/her own entries?
		 if($SESS->userdata('member_id') == $authorid) {
			if($SESS->userdata('can_delete_self_entries') == "n") {
				$this->usermessage .= $this->permission_error;
				return $this->usermessage;
			}
		 }	 
		 // Is the user allowed to delete other user's entries?		 
		 else {
			if($SESS->userdata('can_delete_all_entries') == "n") {
				$this->usermessage .= $this->permission_error;
				return $this->usermessage;
			}
		 }		 
	 }
	 
	  // User is allowed to delete this entry, so get on with it...
  	 $DB->query("DELETE FROM exp_weblog_titles WHERE entry_id = '{$entryid}'");
	 $DB->query("DELETE FROM exp_weblog_data WHERE entry_id = '{$entryid}'");
	 $DB->query("DELETE FROM exp_category_posts WHERE entry_id = '{$entryid}'");
	 $DB->query("DELETE FROM exp_trackbacks WHERE entry_id = '{$entryid}'");
	 $DB->query("DELETE FROM exp_relationships WHERE rel_parent_id = '{$entryid}'");

	 // Update the total entries count for the user that posted this entry
	 $query = $DB->query("SELECT total_entries FROM exp_members WHERE member_id = '".$authorid."'");

	 $tot = $query->row['total_entries'];
	
	 if ($tot > 0)
		 $tot -= 1;

	 $DB->query("UPDATE exp_members set total_entries = '".$tot."' WHERE member_id = '".$authorid."'");
	 
	 // Remove associated comments
	 $query = $DB->query("SELECT count(*) AS count FROM exp_comments WHERE status = 'o' AND entry_id = '$entryid' AND author_id = '".$authorid."'");

	 if ($query->row['count'] > 0)
	 {
		$count = $query->row['count'];
	
		$query = $DB->query("SELECT total_comments FROM exp_members WHERE member_id = '".$authorid."'");

		$DB->query("UPDATE exp_members set total_comments = '".($query->row['total_comments'] - $count)."' WHERE member_id = '".$authorid."'");                
	 }

	 $DB->query("DELETE FROM exp_comments WHERE entry_id = '$entryid'");
	
	 // Update statistics	
	 $STAT->update_weblog_stats($weblog_id);
	 $STAT->update_comment_stats($weblog_id);
	 $STAT->update_trackback_stats($weblog_id);
	 	 
	 // Show a success message and 'return to previous page' link if requested
	 if($TMPL->fetch_param('returnlink') == "true") {
	 	$prevpage = ($SESS->tracker['1'] == "index" ? "" : $SESS->tracker['1']);
		$returnlink = "<a href=\"" . $PREFS->ini('site_url') . $PREFS->ini('site_index') . 
		$prevpage . "\">" . $this->returntext . "</a>";
	 	$this->usermessage = $this->successmsg . "<br /><br />$returnlink";
		return $this->usermessage;
	 }
	 // Otherwise just show the successful deletion message
	 else {
	 	$this->usermessage = $this->successmsg;
		return $this->usermessage;
	 }
  }

  // ----------------------------------------
  //  Plugin Usage
  // ----------------------------------------

  function usage()
  {
  ob_start(); 
  ?>
The delete entry plugin enables your site users to delete entries from outside of the EE control panel if they have the appropriate permissions. You can modify the various messages that the script outputs by changing the values in the config section of pi.delete_entry.php. The plugin has two functions:

GENERATE 'DELETE' LINKS - {exp:delete_entry:link}

This tag is used in pairs and generates the URL to the entry-specific deletion page. There are four available parameters with the link function:

 - entryid (Required) - The entry_id of the weblog entry you wish to display a delete link for. E.g. 47
 - template (Required) - The name of the template containing the {exp:delete_entry:delete} plugin code. E.g. site/delete
 - showconfirm (Optional) - If this is set to "false" then the javascript "are you sure?" confirmation box will not appear. Defaults to true.
 - entrytype (Optional) - Makes it possible to modify the text displayed in the confirmation box. E.g. an entrytype of "image" would result in a confirmation message of "Are you sure you want to delete this image?". Defaults to 'entry'.

Example usage inside a weblog entries tag: 
{exp:delete_entry:link entryid="{entry_id}" entrytype="image" template="site/delete"}Delete{/exp:delete_entry:link}


DELETE ENTRIES - {exp:delete_entry:delete}

This tag should be embedded in a special 'delete entry' template. You can wrap as little or as much HTML around the tag as you like to ensure that the page is styled to suit your site. The user message (e.g. entry successfully deleted) will appear wherever the tag itself is placed. Currently the plugin is only designed to delete one entry at a time, so you should never embed more than one copy of the tag in a page. All of the standard user EE access checks are completed before a user is allowed to delete the entry, so ensure that your member group permissions are set very carefully.

This function only has one parameter:

 - returnlink (Optional) - If this is set to "true" then a link to the previous page will appear following a successful entry deletion. The text of this link can be adjusted by changing the value of $returntext in pi.delete_entry.php. Defaults to false.
 
Example usage:
 
{exp:delete_entry:delete returnlink="true"}

IMPORTANT NOTE

Given that this entry allows the removal of the removal of ANY weblog data dependant on member group permissions you should take massive amounts of care to ensure these are set up correctly. Care should also be exercised with the delete link tag as users will receive no prompt if javascript is not enabled in their browser (or if showconfirm is disabled). 

You use this plugin at your own risk and I accept no responsibility for any loss of data (or anything else for that matter) resulting from the use of this script. Unless you really need to grant users access to delete certain types of entry without granting them access to the control panel I would not recommend using this plugin. I would not recommend using this plugin simply for added convenience. I'm content that it is fairly secure but this plugin amounts to adding another door to your house, and you wouldn't do that unless you needed to.

USAGE

You may...

 - Use this site on your own or your client's personal or business websites.
 - Modify the code to suit your own or your client's needs.
 
You may not...

 - Distribute this plugin in a modified or unmodified form without my permission. 
 - Sell this plugin at a fee (yes the above covers this, but I want to emphasize that this is FREE and should always remain so.

  <?php
  $buffer = ob_get_contents();
	
  ob_end_clean(); 

  return $buffer;
  }
  // END

}

?>